@@ -3,9 +3,9 @@ package Number::ZipCode::JP::Table::Company;
 use strict;
 use warnings;
 
-our $VERSION = '0.20240229';
+our $VERSION = '0.20240329';
 
-# Table last modified: 2024-02-29
+# Table last modified: 2024-03-29
 our %ZIP_TABLE = (
     '001' => '(?:8(?:5(?:[0-2]1|55|77|88)|612))',
     '002' => '(?:850[1-4])',
@@ -106,11 +106,11 @@ our %ZIP_TABLE = (
     '100' => '(?:(?:8(?:9(?:4[015]|3[0-37]|6[0-2457-9]|8[0-3679]|9[46]|2[0-24679]|1[02-9]|0[1-579]|5[0-35689]|7[013-9])|1(?:7[2468]|1[0137-9]|8[124-9]|2[013-8]|0[1-57-9]|6[05689]|4[0-24]|5[0-24589]|3[0-69])|2(?:28|51|70|0[1357]|8[23578]|3[2-5]|1[4-69]|4[156]|6[0258])|3(?:70|5[015]|3[2358]|2[1245]|0[2367]|4[15]|1[01]|8[038])|5(?:11|33|4[03]|5[058]|6[07]|8[58]|7[57]|2[0-2]|0[235-7])|6(?:55|2[019]|3[19]|6[356]|7[67]|1[07]|0[126]|4[049])|4(?:5[06]|1[015]|0[25]|3[09]|2[147]|[48][48])|0(?:19|5[015]|7[07-9]|8[068]|6[56])|79[1-4])|6(?:1(?:62|7[0-57]|5[0-2])|2(?:55|77|6[02])|0(?:51|66|80)|75[1-6])|149[28]))',
     '101' => '(?:8(?:4(?:1[0568]|6[0-246]|7[057]|4[13-68]|3[0379]|8[05]|0[58]|5[0169]|2[1-59])|6(?:8[28]|0[356]|5[146]|6[578]|3[01367]|7[026]|4[235-8]|2[146-9]|1[01679])|3(?:8[38]|5[013-589]|4[367]|0[17-9]|3[3568]|1[0138]|2[3-69]|7[258]|6[267])|5(?:3[0-245]|6[1258]|7[59]|4[28]|1[25]|0[249]|8[0569]|2[0-578]|5[24589])|7(?:0[137]|1[0-25-8])|9(?:41|50|7[37]|8[36])|2(?:28|0[14]|1[0359])|0(?:11|5[04]|0[128])|1(?:01|89)))',
     '102' => '(?:8(?:1(?:2[02-58]|8[124-8]|5[0-25]|3[0-289]|0[1-39]|7[0-25-8]|9[0-5]|4[0-24]|6[016]|1[0-257-9])|5(?:0[2-468]|4[013]|5[2-9]|7[01378]|3[0-39]|2[02589]|1[0-3569]|6[013-79]|8[023568])|6(?:3[0-3579]|4[2-5]|2[0-26-8]|8[0589]|7[17-9]|1[0-47-9]|5[0156]|6[06-8]|0[1-4679])|4(?:7[047]|6[0-24-68]|5[0-259]|0[124-7]|4[0158]|2[0146]|8[489]|3[037]|1[01479])|2(?:5[015]|7[2357]|3[0-24-68]|6[045]|8[28]|2[1-68]|[01][15]|4[016])|3(?:7[0-37]|3[1-36]|2[124]|1[0134]|8[1-38]|6[24]|4[139]|5[0367]|0[1359])|0(?:30|77|8[0-358]|2[256]|5[05]|0[58]|1[125689])|7(?:30|9[58])))',
-    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[024578]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
-    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|5(?:8[01458]|2[136-8]|5[014-689]|6[068]|3[03689]|1[0278]|4[35-8]|0[1256])|4(?:3[013589]|5[056]|1[369]|0[124-8]|8[168]|2[0-469]|6[078]|4[02-49])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
-    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:3[01358]|2[235]|0[1-8]|1[0-57-9])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
+    '103' => '(?:8(?:4(?:7[0-3]|0[1-57]|6[0-24-68]|4[38]|3[0-589]|1[0-79]|2[24-7]|8[02457-9]|5[016])|2(?:5[0-2569]|3\d|6[01356]|7[036-8]|0[1-68]|8[2457]|1[0-248]|2[124589]|4[013578])|3(?:70|0[1378]|8[0348]|4[15-7]|1[1-478]|5[0-248]|6[036]|3[01357-9]|2[13-58])|5(?:1[0-257]|5[12468]|7[17]|0[1-36]|2[0-25]|6[67]|8[4-68]|3[4-8]|4[238])|6(?:40|5[0136]|3[169]|7[67]|6[068]|8[0469])|0[01]1))',
+    '104' => '(?:(?:8(?:1(?:2[2-589]|5[018]|6[12578]|4[25]|8[389]|7[014-689]|3[0-589]|1[0-24-8]|0[124589])|3(?:1[023579]|7[07-9]|2[458]|8[013689]|6[35]|5[0167]|3[02358]|4[0-5]|0[12467])|4(?:5[06]|3[013589]|1[369]|0[24578]|8[168]|2[0-469]|6[078]|4[02-49])|5(?:3[03]|2[136-8]|4[357]|5[014-689]|6[068]|1[078]|8[1458]|0[1256])|2(?:38|40|71|6[26]|5[124578]|0[568]|8[0-59]|1[0-28])|6(?:14|78|5[06]|8[05]|6[15])|0(?:55|77|1[01]|0[1-37]))|6241))',
+    '105' => '(?:(?:8(?:4(?:7[0-257]|8[2-6]|5[1-36-8]|3[13-7]|[46][014-9]|2[0347-9]|1[0-24-9]|0[1-378])|5(?:6[03578]|1[0-2568]|0[1-357-9]|5[013-8]|8[0-57-9]|7[4-9]|2[1-57-9]|3[0457]|4[03-6])|6(?:7[026-8]|3[04]|8[01569]|6[0568]|1[013-5]|2[0135-7]|5[468]|4[0-24]|0[3468])|3(?:1\d|3[01358]|2[235]|0[1-8])|0(?:10|39|55|0[1258]|7[07]|8[58])|7(?:88|0[127]|1[267]))|7(?:0(?:[58]0|77)|36[5-7]|444)|6[09]50))',
     '106' => '(?:(?:8(?:5(?:6[0-35-79]|0[78]|3[17]|1[458]|7[135-8]|2[12]|5[0-25689]|4[145]|8[0157-9])|6(?:77|4[0-2489]|5[25]|1[16]|6[58]|3[0569]|0[18]|2[0256])|0(?:11|39|0[17])|(?:10|79)7|4(?:01|87))|6(?:1(?:61|88)|06[06])))',
-    '107' => '(?:8(?:4(?:20|34|5[06]|7[127]|0[1-4]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
+    '107' => '(?:8(?:4(?:20|5[06]|7[127]|0[1-4]|3[14]|1[0-26-9]|8[24]|4[08]|6[038])|5(?:[37]2|81|1[14]|0[2578]|2[0178]|6[037]|5[0268]|4[56])|6(?:01|50|66|1[5-79]|7[46]|3[0-3689]|8[068]|2[0357])|3(?:60|4[0289]|7[013]|2[0346]|8[048]|3[026]|5[125])|0(?:[16]0|77|0[16])))',
     '108' => '(?:(?:8(?:5(?:2[0-35]|4[0358]|3[02369]|0[1-9]|6[0468]|1[0-25]|7[0135]|5[0-35-8]|8[0-3568])|3(?:2[25689]|1[0356]|7[2359]|8[013-689]|3[34]|5[058]|6[01]|4[15]|0[13578])|2(?:8[028]|2[0-245]|7[056]|4[0-38]|1[0-25-7]|0[1-36-9]|3[0-4]|5[05])|4(?:56|0[3-57]|2[013-5]|7[078]|1[014-7]|3[29]|6[68]|4[48])|6(?:50|1[0-25-7]|2[28]|3[1-3689]|0[267]|4[0-28])|0(?:[258]0|[17]1|0[15])|7(?:07|1[03])|11[78])|63(?:50|63)))',
     '109' => '(?:8792)',
     '110' => '(?:8(?:5(?:6[0-25-7]|4[01368]|7[5-8]|3[0-4679]|0[1-3579]|1[0135-7]|5[059]|8[02-468]|2[024])|6(?:53|2[0-2568]|6[0259]|3[0158]|4[124-6]|0[259]|8[015-7]|1[04589]|7[35-8])|7(?:8[027]|1[2-6]|2[235]|3[36]|0[68])|408|807))',
@@ -125,7 +125,7 @@ our %ZIP_TABLE = (
     '123' => '(?:85(?:[58]8|40|1[1247]|0[135-9]))',
     '124' => '(?:85(?:60|77|2[04]|3[03589]|0[1-39]|8[58]|5[05]|1[01]))',
     '125' => '(?:8(?:5(?:0[3-8]|8[58]|1[1-47]|2[026])|601))',
-    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:25|71|86|3[367]|5[05]|6[068]|1[125]|0[1-689]|4[024])|7(?:[12]0|0[16])))',
+    '130' => '(?:8(?:5(?:8[03-58]|2[0-258]|7[057]|3[013-589]|5[3-8]|4[3568]|6[135-7]|0[13-9]|1[0-8])|6(?:25|71|86|4[02]|3[367]|5[05]|6[068]|1[125]|0[1-689])|7(?:[12]0|0[16])))',
     '131' => '(?:8(?:5(?:65|1[0-389]|3[03]|2[0467]|5[058]|8[458]|0[1357-9])|139|634|711))',
     '132' => '(?:8(?:5(?:[18]5|33|5[015]|0[137]|6[27])|6(?:01|74|[68][68])|7(?:11|3[029])))',
     '133' => '(?:8(?:5(?:[01]1|8[05]|5[238])|70[46]))',
@@ -133,7 +133,7 @@ our %ZIP_TABLE = (
     '135' => '(?:8(?:5(?:48|7[057-9]|5\d|3[0-358]|2[1-3578]|8[1257]|1[0-478]|0[12458]|6[035-8])|4(?:4[0358]|2[27]|0[24]|5[18]|8[0-2]|7[037]|6[014]|1[15]|3[026])|6(?:86|0[28]|2[0-25]|6[168]|3[0-29]|7[078]|1[014-9]|5[059])|3(?:[25]0|8[3-57]|0[1368]|7[05]|6[023]|3[01]|1[0-28])|1(?:[46]5|21|50|78|1[01458]|0[89]|3[0479]|8[01])|7(?:97|3[0-3]|2[0-37]|0[17]|1[0178])|2(?:10|2[24])|0(?:74|80)))',
     '136' => '(?:8(?:5(?:3[135]|4[03]|5[056]|8[01589]|1[2357]|7[057]|6[07]|0[1257]|2[1-35])|6(?:51|8[06]|1[25]|[37][0157]|2[0267]|6[68]|4[08]|0[3578])|7(?:[23]3|11)|88[08]|405|908))',
     '137' => '(?:8(?:6(?:23|86)|08[18]|581))',
-    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|6[0367]|2[1-3569]|0[235-9]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
+    '140' => '(?:8(?:5(?:90|4[0137-9]|3[0136-9]|7[1-46]|8[0346]|0[236-9]|6[0367]|2[1-3569]|5[1248]|1[1256])|6(?:4[04]|3[0147]|6[013689]|2[13568]|7[025-8]|5[03-68]|0[12]|8[0278]|1[14-79])|7(?:88|1[015-7]|2[12]|0[279])|810))',
     '141' => '(?:8(?:6(?:3[017-9]|0[2-79]|8[048]|6[03-5]|2[03679]|1[01356]|7[1-379]|4[0-46-8]|5[06-8])|5(?:34|4[04]|6[0-25-9]|5[59]|2[0-25]|0[13-57]|1[02579]|8[0-248]|7[267])|4(?:8[78]|1[1-3689]|2[0-6])|2(?:55|60|1[04]|0[1-6])|7(?:1[056]|0[17])|001|924))',
     '142' => '(?:8(?:5(?:[01]1|33|40|5[058])|6(?:11|22|66)|777))',
     '143' => '(?:85(?:70|5[02578]|3[013589]|2[0158]|8[05]|6[0578]|1[13-5]|0[2457-9]|4[014]))',
@@ -153,7 +153,7 @@ our %ZIP_TABLE = (
     '161' => '(?:8(?:5(?:08|11|75|3[19]|6[057]|5[236-8]|4[0156]|2[0-28])|710))',
     '162' => '(?:8(?:6(?:[78]0|1[24-6]|2[0468]|5[04-6]|[36][689]|4[046]|0[1248])|4(?:33|5[015]|6[04]|4[058]|7[1368]|8[048]|0[27]|2[12]|1[125])|5(?:75|[16][25]|0[235]|3[05]|8[57]|5[16-8]|4[034])|8(?:30|5[03]|0[1-8]|6[01])|0(?:55|60|2[0-2]|0[15])|7(?:0[17]|1[016-8])|953))',
     '163' => '(?:(?:0(?:5(?:5[378]|7[056]|6[0269])|6(?:7[5-7]|5[59]|6[359])|8(?:50|67|3[136])|2(?:78|6[18])|4(?:56|7[18])|9(?:43|3[68])|7[27]7)|1(?:3(?:50|63|71|4[59]|8[28])|0(?:7[13]|6[156]|5[35])|4(?:55|70|88)|5(?:88|3[37]))|8(?:6(?:02|80|2[06]|3[89]|7[17]|6[016])|0(?:0[13]|8[0-2]|1[29])|5(?:35|48))))',
-    '164' => '(?:8(?:5(?:[37]0|12|67|4[015]|2[25]|8[58]|5[05]|0[1-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
+    '164' => '(?:8(?:5(?:[37]0|12|55|67|4[015]|2[25]|8[58]|0[1-5])|6(?:[25]0|[68]6|7[78]|1[167]|4[24]|[03][18])|7(?:25|0[15])))',
     '165' => '(?:8(?:(?:63|78)0|555))',
     '166' => '(?:85(?:20|88|0[1-3]|6[5-7]|4[025]|3[1-357-9]|7[078]))',
     '167' => '(?:8(?:5(?:[26]0|34|85|0[15-7]|1[05]|5[15])|6(?:10|28|0[12])|001))',
@@ -255,7 +255,7 @@ our %ZIP_TABLE = (
     '276' => '(?:85(?:01|80|2[3-7]))',
     '277' => '(?:8(?:5(?:1[1589]|0[13-57]|8[124-9]|5[0146-8]|3[139]|2[0-2]|7[0-479]|6[1-69])|6(?:86|5[45]|6[16])))',
     '278' => '(?:8(?:5(?:[02]1|10|33|7[07]|5[05])|6(?:01|86)))',
-    '279' => '(?:8(?:5(?:41|67|5[0358]|8[0-358]|0[1-356]|2[124-69]|1[16-9]|3[0-2])|6(?:01|86)))',
+    '279' => '(?:8(?:5(?:41|67|70|0[1-6]|5[0358]|8[0-358]|2[1-35-79]|1[1269]|3[0-2])|6(?:01|86)))',
     '282' => '(?:86(?:02|10))',
     '283' => '(?:(?:8(?:5(?:11|55|88|0[15])|6(?:50|86)|701)|0195))',
     '284' => '(?:8555)',
@@ -383,7 +383,7 @@ our %ZIP_TABLE = (
     '407' => '(?:(?:85(?:11|49|55|0[12])|0192))',
     '408' => '(?:(?:85(?:22|33|85|5[05]|1[15])|01(?:88|92)))',
     '409' => '(?:(?:3(?:8(?:8[03589]|9[2-8])|39[23]|79[23]|293|692)|2(?:19[2-6]|59[2378]|398|992)|1(?:298|392)|019[2358]))',
-    '410' => '(?:(?:8(?:5(?:67|75|3[03]|0[148]|5[0-258]|8[058]|2[02]|4[0135]|1[0145])|6(?:10|8[69]|5[45]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-8]|39[2-6])|0(?:19[25]|39[68])|3(?:69[36]|292)))',
+    '410' => '(?:(?:8(?:5(?:67|75|3[03]|0[148]|5[0-258]|8[058]|2[02]|4[0135]|1[0145])|6(?:10|55|8[69]|0[12])|7(?:10|39))|2(?:39[2-6]|19[2-5]|29[257]|592)|1(?:19[2-8]|39[2-6])|0(?:19[25]|39[68])|3(?:69[36]|292)))',
     '411' => '(?:8(?:5(?:02|33|60|77|88|2[05]|5[15]|[14][01])|6(?:30|89|2[03]|4[148]|6[068]|5[0-2]|1[01])|7(?:[45]0|[78]7|2[025]|3[01])))',
     '412' => '(?:8(?:5(?:24|50|85|1[1-3]|0[15])|6(?:3[04]|0[159])|701))',
     '413' => '(?:(?:8(?:5(?:30|8[59]|0[25]|5[058]|6[067]|1[01])|6(?:26|78|1[18]))|0(?:29[238]|49[23]|196)))',
@@ -488,7 +488,7 @@ our %ZIP_TABLE = (
     '516' => '(?:(?:8(?:5(?:20|77|3[03]|5[0-58]|8[018]|4[3-9]|6[67]|1[12568]|0[1-35])|6(?:86|0[12]))|1(?:19[2568]|492)|019[2-48]|2195))',
     '517' => '(?:(?:0(?:59[23]|292|494)|85(?:01|1[17])))',
     '518' => '(?:(?:0(?:29[2-68]|49[2-6]|192)|85(?:01|18|33)))',
-    '519' => '(?:(?:0(?:19[35-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
+    '519' => '(?:(?:0(?:19[3-8]|49[2357]|59[2-5]|292|393|696)|3(?:69[2-6]|[24]92)|2(?:59[23]|[17]92)|439[2-6]|529[23]|1192))',
     '520' => '(?:(?:8(?:5(?:[23]0|01|67|8[0568]|1[0-356]|7[057]|5[058])|6(?:39|66))|3(?:1(?:9[45]|8[02589])|08[0-58]|28[12589]|49[23]|393)|2(?:39[2-5]|59[24-6]|19[24]|492)|1(?:1(?:88|92)|[2568]92|49[25])|0(?:2(?:87|92)|58[08])))',
     '521' => '(?:(?:1(?:29[25]|39[28]|192)|8(?:60|5[01])1|0[23]92))',
     '522' => '(?:(?:8(?:5(?:11|0[135]|4[03]|3[39]|8[58]|2[023])|6(?:55|66))|029[27]))',
@@ -527,7 +527,7 @@ our %ZIP_TABLE = (
     '556' => '(?:8(?:5(?:[38]5|1[056]|0[13]|5[058])|6(?:01|70|6[03-6])))',
     '557' => '(?:8501)',
     '558' => '(?:85(?:01|85|5[58]))',
-    '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[126]|6[01])|6(?:11|0[1245]|5[18])|729))',
+    '559' => '(?:8(?:5(?:1[019]|5[03589]|8[58]|0[126]|6[01])|6(?:11|58|0[1245])|729))',
     '560' => '(?:85(?:79|80|4[38]|5[0-25]|6[0157]|3[12]|0[56]))',
     '561' => '(?:85(?:[23]0|01|77|5[058]|1[01]))',
     '562' => '(?:8(?:5(?:11|22|43|55|8[0568]|0[58]|6[0278])|6(?:78|86)))',
@@ -563,7 +563,7 @@ our %ZIP_TABLE = (
     '594' => '(?:(?:8(?:50[12]|686)|119[28]))',
     '595' => '(?:8(?:6(?:50|86)|5[58]5))',
     '596' => '(?:8(?:5(?:10|22|88)|6(?:[25]4|86)))',
-    '597' => '(?:8(?:5(?:22|55|8[58]|0[12]|1[15])|686))',
+    '597' => '(?:8(?:5(?:22|55|77|8[58]|0[12]|1[15])|686))',
     '598' => '(?:85(?:[13]1|22|40|6[06]|0[389]|5[05]))',
     '599' => '(?:(?:0[23]92|8531))',
     '600' => '(?:8(?:5(?:44|3[03]|6[5-7]|1[19]|5[058]|0[1-356]|7[07]|8[168]|2[0256])|6(?:01|52|65|8[68])|7(?:11|87|92)))',
@@ -896,7 +896,7 @@ our %ZIP_TABLE = (
     '937' => '(?:8(?:5(?:[58]5|03|11|6[67])|6(?:01|60|78)))',
     '938' => '(?:(?:8(?:6(?:1[0-3]|0[12])|5(?:[58]5|0[25]))|029[23]))',
     '939' => '(?:(?:8(?:5(?:21|67|0[127]|[58][058]|1[0157]|7[12])|6(?:01|50|3[06]|4[02]|1[01]))|1(?:39[2-8]|89[23578]|59[2356]|69[2-48]|19[23]|99[78]|492)|0(?:29[2-6]|79[2358]|39[258]|[15]92|693)|2(?:29[23578]|39[238]|69[24]|192|595|798)|3593))',
-    '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2])|707)|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|59[25]|[34]92)|029[2-8]|119[3-68]))',
+    '940' => '(?:(?:8(?:5(?:67|7[027]|3[02]|2[12]|0[18]|5[0458]|1[01]|8[03568])|6(?:41|60|86|3[013]|5[0134]|0[235]|[12][0-2]))|2(?:1(?:8[1-468]|9[258])|0(?:93|8[1-358])|59[25]|[34]92)|029[2-8]|119[3-68]))',
     '941' => '(?:8(?:6(?:[01]1|86)|50[12]))',
     '942' => '(?:(?:8(?:5(?:63|0[1258])|6(?:[01]1|66))|0(?:19[2-6]|39[238]|492)|1492))',
     '943' => '(?:(?:8(?:5(?:61|1[025]|4[045]|3[0134]|2[0-25]|8[58]|5[125]|0[1-35])|6(?:1[06]|0[147]))|0(?:19[23]|595|692)))',
